pub enum ChangeKind<P: Primitive> {
Added(P),
NodeAdded(Node<P>),
Removed(P),
NodeRemoved(Node<P>),
Modified(P, P),
SequenceChange(Vec<Edit<Node<P>>>),
}Expand description
Represents a change in a possibly recursive structure.
Added, Removed, Modified are actions on leaves.
NodeAdded, NodeRemoved are actions on nodes.
SequenceChange contains the raw Myers edit script for a sequence.
Note
We don’t diff recursively inside lists as Rust lacks facilities
to dispatch between Vec<Primitive> and Vec<Node<Primitive>>.
For this reason we always apply Myers.
Variants
Added(P)
NodeAdded(Node<P>)
Removed(P)
NodeRemoved(Node<P>)
Modified(P, P)
SequenceChange(Vec<Edit<Node<P>>>)