Skip to main contentModule recursive
Source - Change
- Represents a single change in a possibly recursive structure
- ChangeKind
- Represents a change in a possibly recursive structure.
- Node
- Represents a single Node.
We transform input structures into Node trees in order to recursively diff them
- PathSegment
- Represents either a list index or a map key
- Diffable
- Trait to transform a given structure into a
[Node] tree or viceversa. - Primitive
- Trait for leaf values in a Node tree.
Implemented for all Rust primitives except floats, which lack
[Eq]
- apply
- Applies a list of changes to an input. Reverse of
diff - diff
- Builds a list of changes for two nodes.